Module error

Module error 

Enums

ParsingError
The error type returned by all the parsing functions in this crate.

Type Aliases

ParsingResult
The result type returned by all the parsing functions in this crate.