pub type ParsingResult<'a, T> = Result<T, ParsingError<'a>>;Expand description
The result type returned by all the parsing functions in this crate.
Aliased Type
pub enum ParsingResult<'a, T> {
Ok(T),
Err(ParsingError<'a>),
}pub type ParsingResult<'a, T> = Result<T, ParsingError<'a>>;The result type returned by all the parsing functions in this crate.
pub enum ParsingResult<'a, T> {
Ok(T),
Err(ParsingError<'a>),
}